qemacs-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Qemacs-commit] qemacs extras.c qe-doc.html qe-doc.texi qe.c qe...


From: Charlie Gordon
Subject: [Qemacs-commit] qemacs extras.c qe-doc.html qe-doc.texi qe.c qe...
Date: Tue, 22 Apr 2008 09:28:34 +0000

CVSROOT:        /cvsroot/qemacs
Module name:    qemacs
Changes by:     Charlie Gordon <chqrlie>        08/04/22 09:28:34

Modified files:
        .              : extras.c qe-doc.html qe-doc.texi qe.c qe.h 
                         qeconfig.h 

Log message:
        renamed universal argument as numeric argument

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/qemacs/extras.c?cvsroot=qemacs&r1=1.5&r2=1.6
http://cvs.savannah.gnu.org/viewcvs/qemacs/qe-doc.html?cvsroot=qemacs&r1=1.10&r2=1.11
http://cvs.savannah.gnu.org/viewcvs/qemacs/qe-doc.texi?cvsroot=qemacs&r1=1.6&r2=1.7
http://cvs.savannah.gnu.org/viewcvs/qemacs/qe.c?cvsroot=qemacs&r1=1.90&r2=1.91
http://cvs.savannah.gnu.org/viewcvs/qemacs/qe.h?cvsroot=qemacs&r1=1.89&r2=1.90
http://cvs.savannah.gnu.org/viewcvs/qemacs/qeconfig.h?cvsroot=qemacs&r1=1.33&r2=1.34

Patches:
Index: extras.c
===================================================================
RCS file: /cvsroot/qemacs/qemacs/extras.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -b -r1.5 -r1.6
--- extras.c    20 Apr 2008 12:01:34 -0000      1.5
+++ extras.c    22 Apr 2008 09:28:33 -0000      1.6
@@ -423,7 +423,7 @@
 
     qe_register_cmd_table(extra_commands, NULL);
     for (key = KEY_META('0'); key <= KEY_META('9'); key++) {
-        qe_register_binding(key, "universal-argument", NULL);
+        qe_register_binding(key, "numeric-argument", NULL);
     }
     return 0;
 }

Index: qe-doc.html
===================================================================
RCS file: /cvsroot/qemacs/qemacs/qe-doc.html,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -b -r1.10 -r1.11
--- qe-doc.html 4 Apr 2008 18:26:55 -0000       1.10
+++ qe-doc.html 22 Apr 2008 09:28:33 -0000      1.11
@@ -63,7 +63,7 @@
 UNIX editor. It has features that even big editors lack :
 </p><ul class="toc">
 <li> Full screen editor with an Emacs look and feel with all Emacs common
-  features: multi-buffer, multi-window, command mode, universal
+  features: multi-buffer, multi-window, command mode, numeric
   argument, keyboard macros, config file with C like syntax, minibuffer
   with completion and history.
 
@@ -431,7 +431,7 @@
 <h2 class="section"> 3.8 Command handling </h2>
 
 <table><tr><td>&nbsp;</td><td><pre class="example">M-x                     : 
execute-command
-C-u                     : universal-argument
+C-u                     : numeric-argument
 C-g                     : abort
 C-x u, C-_              : undo
 C-x (                   : start-kbd-macro

Index: qe-doc.texi
===================================================================
RCS file: /cvsroot/qemacs/qemacs/qe-doc.texi,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -b -r1.6 -r1.7
--- qe-doc.texi 3 Jan 2008 09:51:31 -0000       1.6
+++ qe-doc.texi 22 Apr 2008 09:28:33 -0000      1.7
@@ -14,7 +14,7 @@
 @itemize
 
 @item Full screen editor with an Emacs look and feel with all Emacs common
-  features: multi-buffer, multi-window, command mode, universal
+  features: multi-buffer, multi-window, command mode, numeric
   argument, keyboard macros, config file with C like syntax, minibuffer
   with completion and history.
 
@@ -207,7 +207,7 @@
 
 @example
 M-x                     : execute-command
-C-u                     : universal-argument
+C-u                     : numeric-argument
 C-g                     : abort
 C-x u, C-_              : undo
 C-x (                   : start-kbd-macro

Index: qe.h
===================================================================
RCS file: /cvsroot/qemacs/qemacs/qe.h,v
retrieving revision 1.89
retrieving revision 1.90
diff -u -b -r1.89 -r1.90
--- qe.h        22 Apr 2008 08:15:04 -0000      1.89
+++ qe.h        22 Apr 2008 09:28:33 -0000      1.90
@@ -1673,7 +1673,7 @@
 void exec_command(EditState *s, CmdDef *d, int argval, int key);
 void do_execute_command(EditState *s, const char *cmd, int argval);
 void window_display(EditState *s);
-void do_universal_argument(EditState *s);
+void do_numeric_argument(EditState *s);
 void do_start_macro(EditState *s);
 void do_end_macro(EditState *s);
 void do_call_macro(EditState *s);

Index: qe.c
===================================================================
RCS file: /cvsroot/qemacs/qemacs/qe.c,v
retrieving revision 1.90
retrieving revision 1.91
diff -u -b -r1.90 -r1.91
--- qe.c        22 Apr 2008 08:21:24 -0000      1.90
+++ qe.c        22 Apr 2008 09:28:33 -0000      1.91
@@ -707,7 +707,7 @@
         argval = 1;
     }
 
     /* save kill if universal argument given */
     endpos = s->offset;
     for (i = argval; i > 0 && endpos < s->b->total_size; i--) {
         eb_nextc(s->b, endpos, &endpos);
@@ -745,7 +745,7 @@
         }
         argval = 1;
     }
     /* save kill if universal argument given */
     do_delete_char(s, -argval);
 }
 
@@ -4032,7 +4032,7 @@
     return buf;
 }
 
-void do_universal_argument(__unused__ EditState *s)
+void do_numeric_argument(__unused__ EditState *s)
 {
     /* nothing is done there (see qe_key_process()) */
 }
@@ -4041,7 +4041,7 @@
     int argval;
     int noargval;
     int sign;
-    int is_universal_arg;
+    int is_numeric_arg;
     int is_escape;
     int nb_keys;
     int describe_key; /* if true, the following command is only displayed */
@@ -4081,7 +4081,7 @@
 /* init qe key handling context */
 static void qe_key_init(QEKeyContext *c)
 {
-    c->is_universal_arg = 0;
+    c->is_numeric_arg = 0;
     c->is_escape = 0;
     c->noargval = 1;
     c->argval = NO_ARG;
@@ -4185,7 +4185,7 @@
         /* no key found */
         if (c->nb_keys == 1) {
             if (!KEY_SPECIAL(key)) {
-                if (c->is_universal_arg) {
+                if (c->is_numeric_arg) {
                     if (qe_isdigit(key)) {
                         if (c->argval == NO_ARG)
                             c->argval = 0;
@@ -4224,9 +4224,9 @@
     if (c->nb_keys == kd->nb_keys) {
     exec_cmd:
         d = kd->cmd;
-        if (d->action.ES == do_universal_argument && !c->describe_key) {
-            /* special handling for universal argument */
-            c->is_universal_arg = 1;
+        if (d->action.ES == do_numeric_argument && !c->describe_key) {
+            /* special handling for numeric argument */
+            c->is_numeric_arg = 1;
             if (key == KEY_META('-')) {
                 c->sign = -c->sign;
                 if (c->noargval == 1)
@@ -4236,7 +4236,7 @@
             }
             c->nb_keys = 0;
         } else {
-            if (c->is_universal_arg) {
+            if (c->is_numeric_arg) {
                 if (c->argval == NO_ARG)
                     c->argval = c->noargval;
                 c->argval *= c->sign;
@@ -707,7 +707,7 @@
     }
 
-    /* save kill if universal argument given */
+    /* save kill if numeric argument given */
     endpos = s->offset;
     for (i = argval; i > 0 && endpos < s->b->total_size; i--) {
@@ -745,7 +745,7 @@
         argval = 1;
     }
-    /* save kill if universal argument given */
+    /* save kill if numeric argument given */
     do_delete_char(s, -argval);
 }

Index: qeconfig.h
===================================================================
RCS file: /cvsroot/qemacs/qemacs/qeconfig.h,v
retrieving revision 1.33
retrieving revision 1.34
diff -u -b -r1.33 -r1.34
--- qeconfig.h  8 Apr 2008 09:25:16 -0000       1.33
+++ qeconfig.h  22 Apr 2008 09:28:33 -0000      1.34
@@ -199,9 +199,9 @@
           "execute-command", do_execute_command, ESsi,
          "s{Command: }[command]|command|"
          "ui")
     /* M-0 thru M-9 should start universal argument */
     CMD0( KEY_CTRL('u'), KEY_META('-'),
-          "universal-argument", do_universal_argument)
+          "numeric-argument", do_numeric_argument)
     CMD0( KEY_CTRL('g'), KEY_CTRLX(KEY_CTRL('g')),
           "abort", do_break)
     CMD0( KEY_CTRLX('('), KEY_NONE,
@@ -199,9 +199,9 @@
          "s{Command: }[command]|command|"
          "ui")
-    /* M-0 thru M-9 should start universal argument */
+    /* M-0 thru M-9 also start numeric argument */
     CMD0( KEY_CTRL('u'), KEY_META('-'),




reply via email to

[Prev in Thread] Current Thread [Next in Thread]